BitPostion

Struct BitPostion 

struct BitPostion {
    byte: usize,
    bit: u8,
}
The index of a bit in the image buffer.

We do not use a pure usize to avoid overflows on 32-bit targets.

Fields

byte: usizebit: u8

[0..8)